@@ -53,10 +53,12 @@ theme_init (char *name)
 		{KBDILLU,    "active",  theme_bool,   &td.popup_active[POPUP_KBDILLU]},
 		{KBDILLU,    "timeout", theme_int,    &td.popup_time[POPUP_KBDILLU]},
 		{CDROM,      "active",  theme_bool,   &td.popup_active[POPUP_CDROM]},
-		{CDROM,      "timeout", theme_int,    &td.popup_time[POPUP_CDROM]}
+		{CDROM,      "timeout", theme_int,    &td.popup_time[POPUP_CDROM]},
+		{CRTMIRROR,  "active",  theme_bool,   &td.popup_active[POPUP_CRTMIRROR]},
+		{CRTMIRROR,  "timeout", theme_int,    &td.popup_time[POPUP_CRTMIRROR]}
 	};
 
-	td.bgimage		= NULL;  /* window background image */
+	td.bgimage			= NULL;  /* window background image */
 	td.layout_init		= NULL;  /* callbacks for layout renderer */
 	td.layout_attach	= NULL;
 	td.layout_cleanup	= NULL;
@@ -71,6 +73,7 @@ theme_init (char *name)
 	td.popup_time[POPUP_SLEEP]      = TIMEOUT_NOTICE;
 	td.popup_time[POPUP_KBDILLU]    = TIMEOUT_LEVER;
 	td.popup_time[POPUP_CDROM]      = TIMEOUT_NOTICE;
+	td.popup_time[POPUP_CRTMIRROR]  = TIMEOUT_NOTICE;
 
 	strncpy(td.name, name, sizeof(td.name));
 
@@ -124,9 +127,7 @@ theme_load_data (struct theme *td, struct themeoption *tab, int tablen)
 {
 	char linebuffer[150], buffer[200];
 	char *token, *arg, *delim;
-	char *section[] = {"", "brightness", "volume", "mute",
-	                  "mouse", "battery", "sleep", "noaudio",
-	                  "kbdillu", "cdrom"};
+	char *section[] = { SECTIONNAMES };
 	int n, err = 0;
 	FILE *fd;
 
@@ -154,7 +155,7 @@ theme_load_data (struct theme *td, struct themeoption *tab, int tablen)
 		}
 		fclose(fd);
 	} else {
-		print_error (_("ERROR: Couldn't read theme description for %s, %s.\n"), td->name, strerror(errno));
+		print_msg (PBB_ERR, _("Couldn't read theme description for %s, %s.\n"), td->name, strerror(errno));
 		return E_NOFILE;
 	}
 	return err;
@@ -207,7 +208,7 @@ theme_layout (struct theme *td, char *arg, int *data)
 			break;
 		}
 	if (n < 0) {
-		print_error (_("ERROR: Unknown theme layout %s.\n"), arg);
+		print_msg (PBB_ERR, _("Unknown theme layout %s.\n"), arg);
 		return -1;
 	}
 	return 0;
@@ -225,7 +226,7 @@ theme_bgtype (struct theme *td, char *arg, int *data)
 			break;
 		}
 	if (n < 0) {
-		print_error (_("ERROR: Unknown bgtype %s.\n"), arg);
+		print_msg (PBB_ERR, _("Unknown bgtype %s.\n"), arg);
 		return -1;
 	}
 	return 0;
@@ -257,7 +258,7 @@ theme_image (struct theme *td, char *arg, GtkWidget **data)
 			g_object_ref(image);     /* mark image as used */
 			g_object_unref(pixbuf);  /* free pixbuf */
 		} else {
-			print_error (_("ERROR: %s.\n"), error->message);
+			print_msg (PBB_ERR, "%s.\n", error->message);
 			g_error_free (error);
 			return -1;
 		}
