@@ -14,51 +14,39 @@
 
 #include <gtk/gtk.h>
 
-#define GLOBAL			0 /* general options, no popup */
-#define BRIGHTNESS		1
-#define VOLUME			2
-#define MUTE			3
-#define MOUSE			4
-#define BATTERY			5
-#define SLEEP			6
-#define NOAUDIO			7
-#define KBDILLU			8
-#define CDROM			9
+enum { GLOBAL, BRIGHTNESS, VOLUME, MUTE, MOUSE, BATTERY,
+	   SLEEP, NOAUDIO, KBDILLU, CDROM, CRTMIRROR, POPUPS=CRTMIRROR };
 
-#define POPUPS			9
-#define POPUP_BRIGHTNESS	(BRIGHTNESS-1)
-#define POPUP_VOLUME		(VOLUME-1)
-#define POPUP_MUTE		(MUTE-1)
-#define POPUP_NOAUDIO		(NOAUDIO-1)
-#define POPUP_MOUSE		(MOUSE-1)
-#define POPUP_BATTERY		(BATTERY-1)
-#define POPUP_SLEEP		(SLEEP-1)
-#define POPUP_KBDILLU		(KBDILLU-1)
-#define POPUP_CDROM		(CDROM-1)
+#define SECTIONNAMES	"", "brightness", "volume", "mute", "mouse", "battery",\
+                        "sleep", "noaudio", "kbdillu", "cdrom", "crtmirror"
+
+enum { POPUP_BRIGHTNESS, POPUP_VOLUME, POPUP_MUTE, POPUP_NOAUDIO,
+       POPUP_MOUSE, POPUP_BATTERY, POPUP_SLEEP, POPUP_KBDILLU,
+       POPUP_CDROM, POPUP_CRTMIRROR };
 
 #define POPUP_TYPE_PROGRESS	0
 #define POPUP_TYPE_MESSAGE	1
 #define POPUP_TYPE_IMAGE	2
 
-#define VOLUME_MAX		100
+#define VOLUME_MAX			100
 #define BACKLIGHT_MAX		15
-#define KBDILLU_MAX		15
+#define KBDILLU_MAX			15
 
-#define TIMEOUT_MIN		2
+#define TIMEOUT_MIN			2
 #define TIMEOUT_LEVER		7	/* in 10th of a second */
 #define TIMEOUT_NOTICE		15
 
 struct theme {
 	char		name[30];
-	int		bgtype;
+	int			bgtype;
 	GtkWidget	*bgimage;
-	int		popup_active[POPUPS];
-	int		popup_time[POPUPS];
-	struct sample	*volsound;
-	struct sample	*warnsound;
-	int		havesound;
-	int		(*layout_init)();   /* load layout resources, etc. */
-	int		(*layout_attach)();  /* attach a wdget tree to a given window */
+	int			popup_active[POPUPS];
+	int			popup_time[POPUPS];
+	struct sample *volsound;
+	struct sample *warnsound;
+	int			havesound;
+	int			(*layout_init)();   /* load layout resources, etc. */
+	int			(*layout_attach)();  /* attach a wdget tree to a given window */
 	void		(*layout_cleanup)(); /* free mem, etc. */
 	void		(*layout_update)(struct theme *td, GtkWidget *window, int popup, ...);
 	void		*user_data;
